from setuptools import setup

setup(
    name='kmr',
    version='0.1',
    packages=['kmr'],
    description='Godot için basit mod aracı',
    author='senin_adın',
    author_email='email@example.com',
    install_requires=[],
)
